"use strict";
/**
 * Copyright (c) 2019-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const chectl_version_1 = require("../../utils/chectl-version");
const utls_1 = require("../../utils/utls");
const DO_NO_PRINT_WARNING_COMMANDS = new Set([
    'server:deploy',
    'server:update',
    'update',
    'version',
]);
const hook = function (options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!(0, utls_1.isCheFlavor)()) {
            return;
        }
        const commandName = options.Command.id;
        if (DO_NO_PRINT_WARNING_COMMANDS.has(commandName)) {
            // Do nothing
            return;
        }
        try {
            if (yield chectl_version_1.CheCtlVersion.isCheCtlUpdateAvailable(options.config.cacheDir)) {
                core_1.ux.warn('A newer version of chectl is available. Run "chectl update" to update to the newer version.');
            }
        }
        catch (_a) {
            // An error occured while checking for newer version. Ignore it.
        }
    });
};
exports.default = hook;
//# sourceMappingURL=new-version-warning.js.map